# Table of Contents

- [managing-tags-on-fact-sheet](<./managing-tags-on-fact-sheet.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managing Fact Sheet Tags (GraphQL)](<./Managing-Fact-Sheet-Tags-GraphQL.md>)
  - [Adding Tags to a Fact Sheet](<./Managing-Fact-Sheet-Tags-GraphQL/Adding-Tags-to-a-Fact-Sheet.md>)
  - [Removing Tags from a Fact Sheet](<./Managing-Fact-Sheet-Tags-GraphQL/Removing-Tags-from-a-Fact-Sheet.md>)
  - [Was this page helpful?](<./Managing-Fact-Sheet-Tags-GraphQL/Was-this-page-helpful.md>)
